#!/bin/sh
#
# Script to archive appropriate folders
# to the Archive folder.
#
# Tony Paterson
# May 2007
#

# Source function library.
if [ -x /etc/rc.d/init.d/functions ]; then
. /etc/rc.d/init.d/functions
fi

#
# Get the date in the format "Day of Week" and time
# This will mean that we will effectively keep a weeks backup
#
SHORTDATE=`date +%a`


#
# User config section
#
SVRNAME="MythSvr2"
ArchiveFolder=/srv/backup/smb
FileArchiveDir=${ArchiveFolder}/misc_files
LOGFILE=$ArchiveFolder/daily_backup.log


# Cleanup etc
rm -Rf ${ArchiveFolder}
mkdir -p ${ArchiveFolder}
mkdir -p ${FileArchiveDir}


#
# Describe the names of the folders to be backed up
#
# NOTE: "BackupFolder[]" should be an absolute path without
#       the leading "/". Thus "/shares/smb/docs" would now
#       simply be "shares/dmb/docs"
#
BackupFolder[0]="/srv/backup/scripts"
BackupFolderName[0]="Scripts"

BackupFolder[1]="/opt/rh/httpd24/root/etc/httpd"
BackupFolderName[1]="HTTP root opt-rh-httpd24-root-etc-httpd"

BackupFolder[2]="/usr/share/mythtv"
BackupFolderName[2]="MythTV Root usr-share-mythtv"

BackupFolder[3]="/opt/rh/httpd24/root/var/www/html"
BackupFolderName[3]="HTTP DocRoot opt-rh-httpd24-root-var-www-html"

BackupFolder[4]="/usr/share/mythweb"
BackupFolderName[4]="MythWeb Root usr-share-mythweb"


#
# This section backs up a section of misc files
#
BackupFile[0]=/etc/httpd/conf/httpd.conf
BackupFile[1]=/etc/samba/smb.conf
BackupFile[2]=/etc/ssh/ssh_config
BackupFile[3]=/home/mythtv/.mythtv/config.xml
BackupFile[3]=/opt/rh/httpd24/root/etc/httpd/conf.d/mythweb.conf



##############################
#
# Begin main backup section
#
echo " " >> $LOGFILE
echo " " >> $LOGFILE
echo "Begining smb file and folder backup " `date` "..."
echo "Begining smb file and folder backup " `date` "..." >> $LOGFILE


#
# Step through each backup folder and archive
#
for (( i = 0; i < ${#BackupFolder[@]} ; i++))
do
   echo "Tar and Gzipping folder ${BackupFolder[$i]}..."
   echo "Tar and Gzipping folder ${BackupFolder[$i]}..." >> $LOGFILE
   ARCHIVE_FULL_NAME="$ArchiveFolder/${BackupFolderName[$i]}""_on_$SVRNAME"".tar.gz"
   echo "ARCHIVE_FULL_NAME = ${ARCHIVE_FULL_NAME}"
   echo "ARCHIVE_FULL_NAME = ${ARCHIVE_FULL_NAME}"  >> $LOGFILE
   tar -zcf "$ARCHIVE_FULL_NAME" -C / "${BackupFolder[$i]}"
done


#
# Backup through individual files
#
for (( i = 0; i < ${#BackupFile[@]} ; i++))
do
   echo "Copying file ${BackupFile[$i]}..."
   echo "Copying file ${BackupFile[$i]}..." >> $LOGFILE
   cp ${BackupFile[$i]} $FileArchiveDir
done


